==> gstep-core-0.5.0.tar.gz: gstep-core-0.5.0/gui/Headers/gnustep/gui/NSBrowserCell.h <==
/* 
   NSBrowserCell.h

   Cell class for the NSBrowser

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author:  Scott Christley <scottc@net-community.com>
   Date: 1996
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

#ifndef _GNUstep_H_NSBrowserCell
#define _GNUstep_H_NSBrowserCell

#include <AppKit/NSCell.h>

@class NSImage;
@class NSTextFieldCell;

@interface NSBrowserCell : NSCell <NSCoding>
{
  // Attributes
  NSImage *_alternateImage;
  NSCell *_branchImage;
  NSCell *_highlightBranchImage;
  NSTextFieldCell *_browserText;
  BOOL _isLeaf;
  BOOL _isLoaded;

  // reserved for the backend
  void *_be_bfc_reserved;
}

//
// Accessing Graphic Attributes 
//
+ (NSImage *)branchImage;
+ (NSImage *)highlightedBranchImage;
- (NSImage *)alternateImage;
- (void)setAlternateImage:(NSImage *)anImage;

//
// Placing in the Browser Hierarchy 
//
- (BOOL)isLeaf;
- (void)setLeaf:(BOOL)flag;

//
// Determining Loaded Status 
//
- (BOOL)isLoaded;
- (void)setLoaded:(BOOL)flag;

//
// Setting State 
//
- (void)reset;
- (void)set;

//
// NSCoding protocol
//
- (void)encodeWithCoder:aCoder;
- initWithCoder:aDecoder;

@end

#endif // _GNUstep_H_NSBrowserCell

==> gstep-core_0.5.0.981229.orig.tar.gz: gstep-core-0.5.0.981229.orig/gui/Headers/gnustep/gui/NSBrowserCell.h <==
/* 
   NSBrowserCell.h

   Cell class for the NSBrowser

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author:  Scott Christley <scottc@net-community.com>
   Date: 1996
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

#ifndef _GNUstep_H_NSBrowserCell
#define _GNUstep_H_NSBrowserCell

#include <AppKit/NSCell.h>

@class NSImage;
@class NSTextFieldCell;

@interface NSBrowserCell : NSCell <NSCoding>
{
  // Attributes
  NSImage *_alternateImage;
  NSImage *_branchImage;
  NSImage *_highlightBranchImage;
  NSCell *_browserText;
  BOOL _isLeaf;
  BOOL _isLoaded;

  // reserved for the backend
  void *_be_bfc_reserved;
}

//
// Accessing Graphic Attributes 
//
+ (NSImage *)branchImage;
+ (NSImage *)highlightedBranchImage;
- (NSImage *)alternateImage;
- (void)setAlternateImage:(NSImage *)anImage;

//
// Placing in the Browser Hierarchy 
//
- (BOOL)isLeaf;
- (void)setLeaf:(BOOL)flag;

//
// Determining Loaded Status 
//
- (BOOL)isLoaded;
- (void)setLoaded:(BOOL)flag;

//
// Setting State 
//
- (void)reset;
- (void)set;

//
// NSCoding protocol
//
- (void)encodeWithCoder:aCoder;
- initWithCoder:aDecoder;

@end

#endif // _GNUstep_H_NSBrowserCell
